aboutsummaryrefslogtreecommitdiff
path: root/include/sway
diff options
context:
space:
mode:
Diffstat (limited to 'include/sway')
-rw-r--r--include/sway/config.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/include/sway/config.h b/include/sway/config.h
index 4ee8c3c2..6024f0f6 100644
--- a/include/sway/config.h
+++ b/include/sway/config.h
@@ -31,10 +31,11 @@ enum binding_input_type {
enum binding_flags {
BINDING_RELEASE=1,
- BINDING_LOCKED=2, // keyboard only
- BINDING_BORDER=4, // mouse only; trigger on container border
- BINDING_CONTENTS=8, // mouse only; trigger on container contents
- BINDING_TITLEBAR=16 // mouse only; trigger on container titlebar
+ BINDING_LOCKED=2, // keyboard only
+ BINDING_BORDER=4, // mouse only; trigger on container border
+ BINDING_CONTENTS=8, // mouse only; trigger on container contents
+ BINDING_TITLEBAR=16, // mouse only; trigger on container titlebar
+ BINDING_RELOAD=32, // the binding runs the reload command
};
/**